@@ -2,6 +2,8 @@ from collections import defaultdict
 from math import sqrt
 from re import split, sub
 
+from similarity import compare_texts
+
 
 INPUT_TEXT = """
 I love the idea of just carrying a paper / pen to write thoughts as they come,
@@ -77,6 +79,10 @@ def punctuation_ratios(text):
     return dict(counts)
 
 
+def similarity_to_twain(text):
+    return compare_texts(text, open('writing_style/mark_twain.txt', 'r').read())
+
+
 def analyze(text):
     return {
         'average_word_lengths': average_word_lengths(text),
@@ -84,6 +90,7 @@ def analyze(text):
         'average_sentence_lengths': average_sentence_lengths(text),
         'stdev_sentence_lengths': stdev_sentence_lengths(text),
         'punctuation_ratios': punctuation_ratios(text),
+        'twain': similarity_to_twain(text),
     }
 
 
